Download Py4J — Py4J

Py4J - A Bridge between Python and Java

### Navigation

- index
- modules |
- Home |
- Download |
- Doc |
- Blog |
- github |
- About »

# Download Py4J

You can download Py4J by using pip, `pip install py4j`, or easy_install, `easy_install py4j`.

Alternatively, you can download the latest version of Py4J from PyPI.

After you have downloaded Py4J, you can follow the Installation instructions or jump to the Getting Started Tutorial.

# Download Py4J for Eclipse

You can download Py4J plug-ins from this update site:

`http://eclipse.py4j.org/`

If you have Java 7+, you can use https:

`https://eclipse.py4j.org/`

# Requirements

Py4J requires:

- A Python interpreter. Py4J has been tested with CPython 2.6, 2.7, and CPython 3.4.
- Java 6.0+.

Py4J for Eclipse requires:

- Eclipse 3.6+ (Eclipse 3.4 and 3.5 should probably work)
- Java 6.0+

If you would like a particular version of Python or Java to be supported, fill a feature request.

### Navigation

- index
- modules |
- Home |
- Download |
- Doc |
- Blog |
- github |
- About »